Struct chess_computer::fen::Fen
source · pub struct Fen {
piece_placement: [[Option<(PieceColor, PieceType)>; 8]; 8],
active_color: PieceColor,
castling_rights: CastlingRights,
ep_target_square: Option<BoardPosition>,
halfmove_clock: i32,
fullmove_number: i32,
}Expand description
A representation of a board state based on FEN notation.
Fields
piece_placement: [[Option<(PieceColor, PieceType)>; 8]; 8]The piece placement.
active_color: PieceColorThe active color.
castling_rights: CastlingRightsThe castling rights.
ep_target_square: Option<BoardPosition>A square over which a pawn has just passed after moving two squares, if available.
halfmove_clock: i32The number of halfmoves since the last capture or pawn advance.
fullmove_number: i32The number of the full moves. It starts at 1 and is incremented after Black’s move.
Implementations
sourceimpl Fen
impl Fen
sourcepub fn from_string(fen_string: &str) -> Self
pub fn from_string(fen_string: &str) -> Self
Creates a new Fen from the given string.
sourcepub fn piece_placement(&self) -> &[[Option<(PieceColor, PieceType)>; 8]; 8]
pub fn piece_placement(&self) -> &[[Option<(PieceColor, PieceType)>; 8]; 8]
Returns the piece placement.
sourcepub fn active_color(&self) -> &PieceColor
pub fn active_color(&self) -> &PieceColor
Returns the active color.
sourcepub fn castling_rights(&self) -> &CastlingRights
pub fn castling_rights(&self) -> &CastlingRights
Returns the castling rights.
sourcepub fn ep_target_square(&self) -> &Option<BoardPosition>
pub fn ep_target_square(&self) -> &Option<BoardPosition>
Returns the en passant target square.
sourcepub fn halfmove_clock(&self) -> &i32
pub fn halfmove_clock(&self) -> &i32
Returns the number of halfmoves since the last capture or pawn advance.
sourcepub fn fullmove_number(&self) -> &i32
pub fn fullmove_number(&self) -> &i32
Returns the number of the full moves.
sourcefn char_to_rank(char: char) -> usize
fn char_to_rank(char: char) -> usize
Converts the given rank char to the corresponding board index.
sourcefn char_to_file(char: char) -> usize
fn char_to_file(char: char) -> usize
Converts the given file char to the corresponding board index.